# PrintUtil By Rambovic45

# Print
class colors:
    WHITE = '\033[0m'
    RED = '\033[91m'
    YELLOW = '\033[93m'
    GREEN = '\033[92m'
    BLUE = '\033[94m'
    CYAN = '\033[96m'
    VIOLET = '\033[95m'
class styles:
    BOLD = '\033[1m'
    RESET = '\033[0m'

def error(msg):
    print(colors.RED + f"[ERROR] {msg}" + styles.RESET)
def succes(msg):
    print(colors.GREEN + f"[SUCCES] {msg}" + styles.RESET)
def warn(msg):
    print(colors.YELLOW + f"[WARN] {msg}" + styles.RESET)
def log(msg):
    print(f"[LOG] {msg}" + styles.RESET)
def custom(color, prefix, text):
    print(color + f"[{prefix}] {text}" + styles.RESET)
def ResetPrint(msg):
    print(msg + styles.RESET)


from setuptools import setup, find_packages

VERSION = '0.0.3'
DESCRIPTION = 'Print with color easily and other cool stuff.'
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# Setting up
setup(
    name="printutil",
    version=VERSION,
    author="Rambovic45",
    author_email="<author@mail.com>",
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Rambovic45/BetterPrints",
    project_urls={
        "Bug Tracker": "https://github.com/Rambovic45/BetterPrints/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=find_packages(where="src"),
    python_requires=">=3.6",
)